Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(306)

Unified Diff: chrome/browser/history/history_service.h

Issue 26563004: Find Favicon in priority of icon_type. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Created 7 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/history/history_service.h
diff --git a/chrome/browser/history/history_service.h b/chrome/browser/history/history_service.h
index 6891f38e71498c86140cb025cf5bfcdd1afeb5a2..611a56d0e03b52ce573eb95e0d321e3cdb4b8d04 100644
--- a/chrome/browser/history/history_service.h
+++ b/chrome/browser/history/history_service.h
@@ -691,19 +691,30 @@ class HistoryService : public CancelableRequestProvider,
CancelableTaskTracker* tracker);
// Used by the FaviconService to get favicons mapped to |page_url| for
// |icon_types| which most closely match |desired_size_in_dip| and
// |desired_scale_factors|. If |desired_size_in_dip| is 0, the largest favicon
// bitmap for |icon_types| is returned. The returned FaviconBitmapResults will
// have at most one result for each of |desired_scale_factors|. If a favicon
// bitmap is determined to be the best candidate for multiple scale factors
// there will be less results. If |icon_types| has several types, results for
// only a single type will be returned in the priority of
// TOUCH_PRECOMPOSED_ICON, TOUCH_ICON, and FAVICON.
CancelableTaskTracker::TaskId GetFaviconsForURL(
const GURL& page_url,
- int icon_types,
+ const std::vector<int>& icon_types_priority,
sky 2013/10/08 23:47:52 Make this take FaviconForURLParams.
michaelbai 2013/10/10 05:51:43 Done.
int desired_size_in_dip,
const std::vector<ui::ScaleFactor>& desired_scale_factors,
+ int threshold_for_next_icon_types,
const FaviconService::FaviconResultsCallback& callback,
CancelableTaskTracker* tracker);
@@ -691,19 +691,30 @@ class HistoryService : public CancelableRequestProvider,
CancelableTaskTracker* tracker);
// Used by the FaviconService to get favicons mapped to |page_url| for
- // |icon_types| which most closely match |desired_size_in_dip| and
- // |desired_scale_factors|. If |desired_size_in_dip| is 0, the largest favicon
- // bitmap for |icon_types| is returned. The returned FaviconBitmapResults will
- // have at most one result for each of |desired_scale_factors|. If a favicon
- // bitmap is determined to be the best candidate for multiple scale factors
- // there will be less results. If |icon_types| has several types, results for
- // only a single type will be returned in the priority of
- // TOUCH_PRECOMPOSED_ICON, TOUCH_ICON, and FAVICON.
+ // icon_types in |icon_types_in_priority| which most closely match
+ // |desired_size_in_dip| and |desired_scale_factors|.
+ // If |desired_size_in_dip| is 0, the largest favicon bitmap for |icon_types|
+ // is returned. The returned FaviconBitmapResults will have at most one
+ // result for each of |desired_scale_factors|. If a favicon bitmap is
+ // determined to be the best candidate for multiple scale factors there will
+ // be less results. If icon_types has several types, results for only a single
+ // type will be returned in the priority of TOUCH_PRECOMPOSED_ICON,
+ // TOUCH_ICON, and FAVICON.
+ // If |icon_types_in_priority| has more than one element, there is only one
+ // icon returned, it is the largest icon which is found according
+ // |desired_size_in_dip| and |desired_scale_factors|, and is the first icon
+ // larger than |threshold_for_next_icon_types| in the order of icon_types
+ // given by |icon_types_priority|.
+ // if none icon is larger than |threshold_for_next_icon_types|, the largest
+ // one among all types of icon is returned.
+ // This feature is especially useful when one type of icon is perfered as
+ // long as its size is larger than a specific value.
CancelableTaskTracker::TaskId GetFaviconsForURL(
const GURL& page_url,

Powered by Google App Engine
This is Rietveld 408576698